/***************************************************************************
**
**  This file is part of geopsy.
**
**  geopsy is free software: you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation, either version 3 of the License, or
**  (at your option) any later version.
**
**  geopsy is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with Foobar.  If not, see <http://www.gnu.org/licenses/>
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2019-08-29
**  Copyright: 2019
**    Marc Wathelet (ISTerre, Grenoble, France)
**
***************************************************************************/

#ifndef SEISMICEVENTWIDGET_H
#define SEISMICEVENTWIDGET_H

#include <QGpGuiTools.h>

#include "ui_SeismicEventWidget.h"

class SeismicEventWidget : public QWidget, private Ui::SeismicEventWidget
{
  Q_OBJECT
public:
  SeismicEventWidget(QWidget * parent=nullptr);
  ~SeismicEventWidget();

  void addActions() {eventView->addActions();}
signals:
  void eventsChanged();
};

#endif // SEISMICEVENTWIDGET_H

